import type { NetworkAdapter, ResourceRequest } from '@luvio/engine';
import { JwtToken } from '@luvio/jwt-manager';
import type { JwtManager } from '@luvio/jwt-manager';
export type ModifyResourceRequestHook<T, E> = (resourceRequest: ResourceRequest, jwtToken: JwtToken<T, E>) => ResourceRequest;
export type RequestTracker = {
    registerHandler: (request: any, name: string, loadedCheck: () => boolean) => void;
    markFinished: (request: any) => void;
};
export type RequestLogger = {
    resolve: (request: ResourceRequest, response: any) => void;
    reject: (request: ResourceRequest, error: Error) => void;
};
/**
 * Adds Authentication for the provided {@link ResourceRequest}
 *
 * @param resourceRequest
 * @param jwt
 * @return
 */
export declare function authenticateRequest<T, E>(resourceRequest: ResourceRequest, jwt: JwtToken<T, E>): ResourceRequest;
/**
 * Wrapper around fetch network adapter from luvio with access to JwtManager {@link JwtManager} to authenticate Request
 * And a hook to update the base URI for the provided {@link ResourceRequest}
 *
 * @param jwtManager: {@link JwtManager}
 * @param modifyResourceRequestHook: {@link ModifyResourceRequestHook}
 * @returns jwtNetworkAdapter {@link NetworkAdapter}
 */
export declare function setupJwtNetworkAdapter<T, E>(jwtManager: JwtManager<T, E>, modifyResourceRequestHook?: ModifyResourceRequestHook<T, E>): NetworkAdapter;
/**
 * Wrapper around fetch network adapter from luvio with access to Aura Client Service getJwtAuthToken() to authenticate Request
 * And a hook to update the base URI for the provided {@link ResourceRequest}
 *
 * @param auraNetworkAdapter: {@link NetworkAdapter}
 * @param modifyResourceRequestHook: {@link ModifyResourceRequestHook}
 * @returns lexJwtNetworkAdapter {@link NetworkAdapter}
 */
export declare function setupLexJwtNetworkAdapter<T, E>(auraNetworkAdapter: NetworkAdapter, modifyResourceRequestHook?: ModifyResourceRequestHook<T, E>, requestTracker?: RequestTracker, requestLogger?: RequestLogger): NetworkAdapter;
